==> org.opennms.features.telemetry.adapters.api-21.0.3-sources.jar: org/opennms/netmgt/telemetry/adapters/api/Adapter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.adapters.api;

import org.opennms.netmgt.collection.api.CollectionSet;
import org.opennms.netmgt.telemetry.config.model.Protocol;
import org.opennms.netmgt.telemetry.ipc.TelemetryMessageLogDTO;

/**
 * Responsible for handling telemetry messages received by the listeners
 * within a protocol definition.
 *
 * The adapter should decode the message and handle the contents appropriately.
 *
 * @author jwhite
 */
public interface Adapter {

    /**
     * A single instance of an adapter will only be responsible
     * for one protocol. The protocol will be set using this method before
     * any calls to {@link #handleMessageLog} are made.
     *
     * @param protocol the protocol in which the adapter is defined
     */
    void setProtocol(Protocol protocol);

    /**
     * Handle the messages.
     *
     * IMPORTANT: Implementations of this method MUST be thread-safe.
     *
     * @param messageLog group of messages to be handled
     */
    void handleMessageLog(TelemetryMessageLogDTO messageLog);

}

==> org.opennms.features.telemetry.adapters.api-23.0.4-sources.jar: org/opennms/netmgt/telemetry/adapters/api/Adapter.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.telemetry.adapters.api;

import org.opennms.netmgt.telemetry.config.api.Protocol;

/**
 * Responsible for handling telemetry messages received by the listeners
 * within a protocol definition.
 *
 * The adapter should decode the message and handle the contents appropriately.
 *
 * @author jwhite
 */
public interface Adapter {

    /**
     * A single instance of an adapter will only be responsible
     * for one protocol. The protocol will be set using this method before
     * any calls to {@link #handleMessageLog} are made.
     *
     * @param protocol the protocol in which the adapter is defined
     */
    void setProtocol(Protocol protocol);

    /**
     * Handle the messages.
     *
     * IMPORTANT: Implementations of this method MUST be thread-safe.
     *
     * @param messageLog group of messages to be handled
     */
    void handleMessageLog(TelemetryMessageLog messageLog);

    void destroy();

}
